@@ -60,8 +60,8 @@ class AccountPositionDao(BaseDao):
     deleteAll = UpdateMethod("truncate account_position")
 
     replaceSave = UpdateMethod("""
-        replace into account_position(id,account_id,shares_code,enable_count)
-        values(:id,':accountId',':sharesCode',':enableCount')
+        replace into account_position(account_id,shares_code,enable_count)
+        values(':accountId',':sharesCode',':enableCount')
     """)
 
     querySharesCodeByAccountId = QueryMethod(
